Python Chemical Kinetics Library
==================================

pychemkin is a Python 3 chemical kinetics library. The core functionality is to compute reaction rates of all species participating in a reaction system. New extended functionality now allows reaction rates and concentrations to be computed as a function of time and to be visualized, in order to facilitate understanding of the timescales upon which the system operates, the production yields of the system, and sensitivity to initial conditions. 

Further documentation is in 'docs/pychemkin.pdf' within the source file.
